<?php

namespace App\Http\Livewire\Generator;

use App\Models\Allowance;
use App\Models\Bid;
use App\Models\Company;
use App\Models\CrisisDemand;
use App\Models\CrisisSupply;
use App\Models\Stock;
use DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Livewire\Component;

class Step2 extends Component
{
    public $amountFrom = 80;
    public $amountTo = 120;
    public $priceFrom = 200;
    public $priceTo = 500;
    public $stockId = null;

    protected $listeners = [
        'generatorAction' => 'refresh'
    ];

    protected $rules = [
        'stockId' => ['required'],
        'amountFrom' => ['required', 'integer'],
        'amountTo' => ['required', 'integer'],
        'priceFrom' => ['required', 'integer'],
        'priceTo' => ['required', 'integer'],
    ];

    protected $messages = [
        'stockId.required' => 'Vyberte prosím výrobek.'
    ];

    public function generateSupplyAndDemand()
    {
        $this->validate();

        $bidsAmount = $this->createBidsForStock(
            $this->stockId,
            $this->amountFrom,
            $this->amountTo
        );

        /*
        $this->distributeDemand(
            $this->stockId,
            $this->demand,
            $this->hospitals
        );

        $this->supply = null;
        $this->demand = null;

        $stock = Stock::findOrFail($this->stockId);
        $stock->crisis_mode = 1;
        $stock->save();
        */

        $this->refresh();
    }

    public function render()
    {
        $this->suppliers = Company::where('type', 1)->count();
        $this->hospitals = Company::where('type', 2)->count();

        return view('generator.step2', [
            'stock' => Stock::query()->pluck('name', 'id'),
            'suppliersCount' => $this->suppliers,
            'hospitalsCount' => $this->hospitals,
        ]);
    }

    public function refresh()
    {

    }

    private function createBidsForStock($stockId, $amountFrom, $amountTo)
    {
        $averagePrice = $this->getAveragePriceFromSuppliers($stockId);

        $companies = CrisisDemand::query()
            ->where('stock_id', $stockId)
            ->pluck('company_id');

        $allowances = Allowance::query()
            ->where('stock_id', $stockId)
            ->whereIn('company_id', $companies)
            ->pluck('amount', 'company_id');

        foreach($allowances as $companyId => $allowance) {

            $demandedAmount = round($allowance * (rand($amountFrom, $amountTo) / 100));

            $price = $this->getAveragePriceFromSuppliers($stockId);

            $price = round($price * (rand($this->priceFrom, $this->priceTo) / 100));

            $bid = new Bid();
            $bid->company_id = $companyId;
            $bid->stock_id = $stockId;
            $bid->type = 'product';
            $bid->price = $price;
            $bid->amount = $demandedAmount;
            $bid->save();

            if($allowance > $demandedAmount) {
                $bid = new Bid();
                $bid->company_id = $companyId;
                $bid->stock_id = $stockId;
                $bid->type = 'selling';
                $bid->price = $price;
                $bid->amount = $allowance - $demandedAmount;
                $bid->save();
            }

            if($demandedAmount > $allowance) {
                $bid = new Bid();
                $bid->company_id = $companyId;
                $bid->stock_id = $stockId;
                $bid->type = 'buying';
                $bid->price = $price;
                $bid->amount = $demandedAmount - $allowance;
                $bid->save();
            }
        }
    }

    private function getAveragePriceFromSuppliers($stockId)
    {
        return CrisisSupply::query()
            ->where('stock_id', $stockId)
            ->average('price');
    }

    private function distributeSupply($stockId, $supply, $suppliersCount, $priceFrom, $priceTo)
    {
        $randomRolls = $this->getRandomValues($suppliersCount);

        $sum = array_sum($randomRolls);

        $distributedValues = [];

        foreach($randomRolls as $value) {
            $distributedValues[] = floor(($value / $sum) * $supply);
        }

        $companies = Company::query()
            ->where('type', 1)
            ->inRandomOrder()
            ->limit($suppliersCount)
            ->get();

        $i = 0;
        foreach($companies as $company) {
            if(!$distributedValues[$i]) {
                continue;
            }

            $supplyItem = new CrisisSupply();
            $supplyItem->stock_id = $stockId;
            $supplyItem->company_id = $company->id;
            $supplyItem->amount = $distributedValues[$i++];
            $supplyItem->price = rand($priceFrom, $priceTo);
            $supplyItem->save();
        }

    }

    private function distributeDemand($stockId, $demand, $hospitals)
    {
        $randomRolls = $this->getRandomValues($hospitals);

        $sum = array_sum($randomRolls);

        $distributedValues = [];

        foreach($randomRolls as $value) {
            $distributedValues[] = floor(($value / $sum) * $demand);
        }

        $companies = Company::query()
            ->where('type', 2)
            ->inRandomOrder()
            ->limit($hospitals)
            ->get();

        $i = 0;
        foreach($companies as $company) {
            if(!$distributedValues[$i]) {
                continue;
            }

            $demandItem = new CrisisDemand();
            $demandItem->stock_id = $stockId;
            $demandItem->company_id = $company->id;
            $demandItem->amount = $distributedValues[$i++];
            $demandItem->save();
        }
    }

    private function getRandomValues($amount)
    {
        $randomRolls = [];

        for($i=0; $i<$amount; $i++) {
            $randomRolls[] = rand(1, 100);
        }

        return $randomRolls;
    }
}
