<?php

namespace App\Models;

use App\Classes\CompanyTypes;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Lab404\Impersonate\Models\Impersonate;
use Laravel\Fortify\TwoFactorAuthenticatable;
use Laravel\Jetstream\HasProfilePhoto;
use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable
{
    use HasApiTokens;
    use HasFactory;
    use HasProfilePhoto;
    use Notifiable;
    use TwoFactorAuthenticatable;
    use HasRoles;
    use Impersonate;

    public function company()
    {
        return $this->belongsTo(Company::class);
    }

    public function isSupplier()
    {
        if(!$this->company_id) {
            return false;
        }

        if($this->company->type !== CompanyTypes::SUPPLIER) {
            return false;
        }

        return true;
    }

    public function isMedicalCenter()
    {
        if(!$this->company_id) {
            return false;
        }

        if($this->company->type !== CompanyTypes::MEDICAL) {
            return false;
        }

        return true;
    }

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'surname',
        'email',
        'password',
        'active',
        'new',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
        'two_factor_recovery_codes',
        'two_factor_secret',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    /**
     * The accessors to append to the model's array form.
     *
     * @var array
     */
    protected $appends = [
        'profile_photo_url',
    ];

    public function canImpersonate() : bool
    {
        return $this->hasRole('admin');
    }

    public function canBeImpersonated() : bool
    {
        return ! $this->hasRole('admin');
    }
}
